fillColor property
Colour the content behind the glass is washed toward (opaque; JSON
"#RRGGBB" or an int ARGB).
Implementation
final Color fillColor;
Colour the content behind the glass is washed toward (opaque; JSON
"#RRGGBB" or an int ARGB).
final Color fillColor;