frostWideMixCentre property
Wide-tail weight where the lens samples at the shape's centre line (sample depth = half the shorter side); see frostWideMixEdge.
Implementation
final double frostWideMixCentre;
Wide-tail weight where the lens samples at the shape's centre line (sample depth = half the shorter side); see frostWideMixEdge.
final double frostWideMixCentre;