frostWideSizeRef property
Shapes whose half shorter side is below this lose wide-tail weight:
w −= frostWideSizeDrop × (1 − halfMin / frostWideSizeRef). 0
disables the size term.
Implementation
final double frostWideSizeRef;
Shapes whose half shorter side is below this lose wide-tail weight:
w −= frostWideSizeDrop × (1 − halfMin / frostWideSizeRef). 0
disables the size term.
final double frostWideSizeRef;