lensSizeRef property
Shapes whose half shorter side is below this get a uniformly scaled-down lens (band, decay and displacement × that ratio); 0 disables it.
Implementation
final double lensSizeRef;
Shapes whose half shorter side is below this get a uniformly scaled-down lens (band, decay and displacement × that ratio); 0 disables it.
final double lensSizeRef;